import { Page } from "@smallstack/api-shared";
import { AxiosApiClient, WidgetDto, DashboardDto } from "@smallstack/axios-api-client";
import { PageableCrudStore } from "@smallstack/store";
export declare abstract class AbstractDashboardStore extends PageableCrudStore<DashboardDto> {
    private axiosApiClient;
    constructor(axiosApiClient: AxiosApiClient);
    protected loadModels(): Promise<Page<DashboardDto>>;
    protected loadModelById(id: string): Promise<DashboardDto>;
    protected deleteModelById(id: string): Promise<void>;
    protected deleteModelsByIds(ids: string[]): Promise<void>;
    protected createModel(dashboard: DashboardDto): Promise<DashboardDto>;
    protected patchModel(id: string, model: Partial<DashboardDto>): Promise<DashboardDto>;
    protected putModel(model: DashboardDto): Promise<DashboardDto>;
    /**
     * This function adds a widget to the current dashboard.
     */
    addWidget(item: WidgetDto): Promise<WidgetDto>;
    /**
     * This function updates a widget from current dashboard.
     */
    updateWidget(widget: WidgetDto): Promise<void>;
    /**
     * This function deletes a widget from the current dashboard.
     */
    deleteWidget(id: string): Promise<void>;
    filterOutDynamicWidgets(dashboard: DashboardDto): DashboardDto;
    /**
     * Filters all widgets based on the predicate. Returns a copy of the dashboards array.
     *
     * @param filterFn All widgets that meet the condition of the filterOutFn will remain.
     */
    filterWidgets(dashboard: DashboardDto, filterFn: (widget: WidgetDto) => boolean): DashboardDto;
}
